==> qtjambi-networkauth-debuginfo-macos-5.15.20.jar: sources/QtJambiNetworkAuth/QAbstractOAuthReplyHandler_shell.h <==
#ifndef QABSTRACTOAUTHREPLYHANDLER_SHELL_H
#define QABSTRACTOAUTHREPLYHANDLER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtNetworkAuth/qabstractoauthreplyhandler.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtJambi/RegistryAPI>


class QAbstractOAuthReplyHandler_shell : public QAbstractOAuthReplyHandler, public QtJambiShellInterface
{
public:
    QAbstractOAuthReplyHandler_shell(QObject* parent0 = nullptr);
    ~QAbstractOAuthReplyHandler_shell() override;

    QString callback() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void networkReplyFinished(QNetworkReply* reply0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractOAuthReplyHandler_access : public QAbstractOAuthReplyHandler
{
    jstring __qt_callback_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_networkReplyFinished_QNetworkReply_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID reply0);
};

#endif // QABSTRACTOAUTHREPLYHANDLER_SHELL_H

==> qtjambi-networkauth-debuginfo-macos-6.5.3.jar: sources/QtJambiNetworkAuth/QAbstractOAuthReplyHandler_shell.h <==
#ifndef QABSTRACTOAUTHREPLYHANDLER_SHELL_H
#define QABSTRACTOAUTHREPLYHANDLER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtNetworkAuth/qabstractoauthreplyhandler.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtJambi/RegistryAPI>


class QAbstractOAuthReplyHandler_shell : public QAbstractOAuthReplyHandler, public QtJambiShellInterface
{
public:
    QAbstractOAuthReplyHandler_shell(QObject* parent0 = nullptr);
    ~QAbstractOAuthReplyHandler_shell() override;

    QString callback() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void networkReplyFinished(QNetworkReply* reply0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractOAuthReplyHandler_access : public QAbstractOAuthReplyHandler
{
    jstring __qt_callback(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_networkReplyFinished_QNetworkReply_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID reply0);
};

#endif // QABSTRACTOAUTHREPLYHANDLER_SHELL_H
